==> preact-chartjs-2-1.0.2.tgz: package/lib/component.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _preact = require('preact');

var _esnext = require('skatejs/esnext');

var _esnext2 = require('@skatejs/renderer-preact/esnext');

var _esnext3 = _interopRequireDefault(_esnext2);

var _index = require('./index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var withComponent = function withComponent(Base) {
  return (0, _esnext.withProps)((0, _esnext.withRenderer)((0, _esnext.withUnique)(Base || HTMLElement)));
};
var SkateComponent = withComponent((0, _esnext3.default)());

function propsWithDefault(type, def) {
  return _extends({}, type, { default: def });
}

var PieWrap = function (_SkateComponent) {
  _inherits(PieWrap, _SkateComponent);

  function PieWrap() {
    _classCallCheck(this, PieWrap);

    return _possibleConstructorReturn(this, _SkateComponent.apply(this, arguments));
  }

  PieWrap.prototype.attachShadow = function attachShadow() {
    return this;
  };

  PieWrap.prototype.renderCallback = function renderCallback(_ref) {
    var props = _ref.props;

    return (0, _preact.h)(_index.Pie, props);
  };

  return PieWrap;
}(SkateComponent);

PieWrap.props = {
  options: _esnext.props.any,
  data: _esnext.props.any
};


customElements.define('pie-chart', PieWrap);

==> preact-chartjs-2-1.0.3.tgz: package/lib/component.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _preact = require('preact');

var _esnext = require('skatejs/esnext');

var _esnext2 = require('@skatejs/renderer-preact/esnext');

var _esnext3 = _interopRequireDefault(_esnext2);

var _index = require('./index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var withComponent = function withComponent(Base) {
  return (0, _esnext.withProps)((0, _esnext.withRenderer)((0, _esnext.withUnique)(Base || HTMLElement)));
};
var SkateComponent = withComponent((0, _esnext3.default)());

function propsWithDefault(type, def) {
  return _extends({}, type, { default: def });
}

var PieWrap = function (_SkateComponent) {
  _inherits(PieWrap, _SkateComponent);

  function PieWrap() {
    _classCallCheck(this, PieWrap);

    return _possibleConstructorReturn(this, _SkateComponent.apply(this, arguments));
  }

  PieWrap.prototype.attachShadow = function attachShadow() {
    return this;
  };

  PieWrap.prototype.renderCallback = function renderCallback(_ref) {
    var props = _ref.props;

    return (0, _preact.h)(_index.Pie, props);
  };

  return PieWrap;
}(SkateComponent);

PieWrap.props = {
  options: _esnext.props.object,
  data: _esnext.props.object
};


customElements.define('pie-chart', PieWrap);
